@@ -2,7 +2,7 @@ use std::fs::{DirBuilder, File};
 use std::io::{Read, Write};
 use std::path::PathBuf;
 
-pub fn write_file(path: PathBuf, file_name: &str, values: &Vec<String>) -> std::io::Result<()> {
+pub fn write_lines(path: PathBuf, file_name: &str, values: &Vec<String>) -> std::io::Result<()> {
     DirBuilder::new().recursive(true).create(path.clone())?;
 
     let path = path.join(file_name);
@@ -16,7 +16,7 @@ pub fn write_file(path: PathBuf, file_name: &str, values: &Vec<String>) -> std::
     Ok(())
 }
 
-pub fn read_file(path: &PathBuf) -> std::io::Result<String> {
+pub fn read_string(path: &PathBuf) -> std::io::Result<String> {
     let mut file = File::open(path)?;
 
     let mut s = String::new();
@@ -24,3 +24,7 @@ pub fn read_file(path: &PathBuf) -> std::io::Result<String> {
 
     Ok(s)
 }
+
+pub fn read_binary(path: &PathBuf) -> std::io::Result<Vec<u8>> {
+    std::fs::read(path)
+}
